@@ -8,9 +8,9 @@ from nusex import CONFIG_DIR, __url__
 
 from ..errors import *
 
-REPO_URL = __url__
+REPO_URL = "https://github.com/nusex/downloads"
 RAW_URL = "https://raw.githubusercontent.com"
-TEMPLATE_SUFFIX = "tree/main/templates"
+TEMPLATE_SUFFIX = "tree/main/templates0x"
 
 
 def _find_templates():
@@ -82,11 +82,23 @@ def _download_templates():
         )
 
 
-def init():
-    details = _get_user_details()
-    _create_config_files(*details)
+def run():
+    if not os.path.isdir(CONFIG_DIR):
+        details = _get_user_details()
+        _create_config_files(*details)
+    else:
+        print(
+            "🔔 Skipping user config. To find out how to update your config, "
+            "run `nsx config -h`."
+        )
+
     _download_templates()
     print(
         "\n🎉 Initialisation complete! You can run this command any time to "
         "get the latest premade templates."
     )
+
+
+def setup(subparsers):
+    subparsers.add_parser("init", description="Initialise nusex.")
+    return subparsers
